#!/bin/sh
#
#
#---------------------------------------------------------------------------
# Description:  Create the RIM object named tmd
#		
# Author:    dtam (April 2000)
#		Modified from the dom_set_rim.sh
# 
# Parameters:   $VENDOR    	 -    Name of RDBMS vendor ('DB2'|'Oracle'|'Sybase'|'MS_SQL')
#               $RIM_HOST        -    Name of the RIM host, must be a TME managed    
#               $DBHOME          -    Database home directory path          
#               $DBID	   	 -    Database ID. (default is tmd)
#               $DBUSER 	 -    Database user ID (default is tmd)
#	        $DBSERVER        -    DB2 only, RDBMS Server ID (or internet protocol)
#	        $DB2INST_HOME    -    DB home path. Only for DB2.
#
# default values: DBID = tmd
#                 DBUSER = tmd
#                 DBPWD = DOMINO      
#            
#                 These are the default value in this script
#                 DB2 users should use the existing user name and password that has access to the tmd database.
#                 Our create database script does not create a new DB2 user.
#
#
# Returns:      0 - normal completion
#               1,2 - abnormal termination
#
# Adjustments :
#
# Defect  ID   Change Description
# ------  ---  -------------------------------------------------------- *
# 104913  TCT  Added script to create RIM object 
# 
#---------------------------------------------------------------------------


preInstallWlookupTmd()
{
  #runs wlookup -r RIM tmd and deletes if it exists
  RIMOID=`wlookup -r RIM $RIMname 2>/dev/null`

  if [ -n "$RIMOID" ]; then
    echo "Deleting RIM object $RIMname" 
    wdel @RIM:tmd  
  fi
}



init()
{
  # Determine local machine to get RIM host
  HOST_OID=`objcall 0.0.0 get_host_location`
  eval RIM_HOST=`idlcall $HOST_OID _get_label`
  

  # Ignore RIM stuff if necessary info is not there 
  if [ -z "$VENDOR" -o -z "$DBHOME" -o -z "$RIM_HOST" ]; then
    echo " Must specify DB vendor, RIM host and installation directory!!" >&2
    exit 1
  fi

  HASopt=0
  if [ -n "$DB2INST_HOME" ]; then
    HASopt=1
  fi
}



createTmdRimObject()
{
  #-----------------------------------------------------------
  # Create the RIM object for user $DBuser. Checks the RIM creation
  # with a wlookup. Exit with error if
  # attempt to create this object fails.
  # There are 2 flavors of 'echo' which have different means of
  # suppressing the new-line at the end.  Pick the appropriate
  # one for each interp.
  #-----------------------------------------------------------
  
  if [ -n "$VENDOR" ]; then
    UNAME=`uname`
    echo "Creating RIM object $RIMname..."
    case $UNAME in
      Windows_NT)
        case $HASopt in
          0)
            echo -n "$DBPWD" | wcrtrim -i  -v "$VENDOR" -H "$DBHOME" \
                 -h "$RIM_HOST" -s "$DBSERVER" -d "$DBID" -u "$DBUSER" "$RIMname"
            ;;
          1)
            echo -n "$DBPWD" | wcrtrim -i -v "$VENDOR" -H "$DBHOME" \
	         -h "$RIM_HOST" -s "$DBSERVER" -I "$DB2INST_HOME" -d "$DBID" -u "$DBUSER" "$RIMname"
	    ;;
	 
        esac
         ;;
      *)
        case $HASopt in
          0)
	     echo "${DBPWD}\c" | wcrtrim  -i -v $VENDOR -H "$DBHOME" \
	       -h "$RIM_HOST" -s "$DBSERVER" -d "$DBID" -u "$DBUSER" "$RIMname"
	     ;;
	  1)
	     echo "${DBPWD}\c" | wcrtrim -i -v $VENDOR -H "$DBHOME" \
	       -h "$RIM_HOST" -s "$DBSERVER" -I "$DB2INST_HOME" -d "$DBID" -u "$DBUSER" "$RIMname"
	     ;;
	 
         esac
          ;;
    esac
  fi
}
	
rimCheckCreate()
{        
  #-----------------------------------------------------------
  # Look up the newly-created object.
  #-----------------------------------------------------------
  RIMID=`wlookup -r RIM "${RIMname}"`

  if [ -z "$RIMID" ]; then
    echo "Error:" >&2
    echo "The options you specified failed to create a RIM object." >&2
    echo "Please check your RDBMS configuration." >&2
    exit 2
  else
    echo "RIM object $RIMname successfully created"
  fi
}



main()
{
  preInstallWlookupTmd
  init
  createTmdRimObject
  rimCheckCreate
}

main



