#!/bin/sh

 #=======================================================================
 #
 # Component:   Tivoli Manager for Domino 3.0
 #
 # Description: Creates the database, tables and user for TMD 3.0 database
 #              (Modified from the dom_cr_db.sh)
 #
 # Author:      dtam
 #
 # Parameters:
 #
 # Returns:       0  - normal completion
 #                >0 - abnormal termination
 #
 # PROPERTY of TIVOLI Systems
 # April, 2000
 #
 # Adjustments :
 #
 # Defect  ID   Change Description
 # ------  ---  --------------------------------------------------------
 # 104913  TCT  Put in scripts to create RIM object and test connection
 # 
 #=======================================================================


#--------------------------------------------------------------------------------
# tmd_cr_db()
#--------------------------------------------------------------------------------

tmd_cr_db()
{
  #set parameters: application name, rim name, db name
  #db user id, db server name
  . ./scripts/init.sh 


  #checks Tivoli authorization  
  . ./scripts/tmeCheck.sh   


  # Checks if RIM object ID for tmd_rim can be accessed
  # if yes, attemps to get RIM type name
  # if either type name or RIM OID is missing, 
  #    sets QUERY_VENDOR=1 to prompt for user input.
  . ./scripts/rimCheckExist.sh    


  #prompts user for RDBMS vendor name if not obtained from RIM
  . ./scripts/findVendor.sh                               
   

  #searches for the create database scripts
  . ./scripts/findCrDbScripts.sh  


  # Checks for RIM connectoin, 
  # Trys to find DB configuration from RIM
  # Prompts user to verify search result. 
  . ./scripts/rimCheckObject.sh 


  # if RIM object is not found, prompts user for RDBMS parameters
  . ./scripts/newRimRdbmsConfig.sh 

  # Sets Oracle specific parameters
  . ./scripts/oracleSpecific.sh  
  
  # For Sybase and MS_SQL 6.x only, assigns DB device 
  # Allows user to do one of the following:
  # 1) create a new db device (with user defined parameters)
  # 2) use existing db device
  . ./dbdevice.sh  
  
  # Sets DB2 specific parameters  
  . ./scripts/db2Specific.sh
  

  # prompts user for the db size
  . ./scripts/setDbSize.sh  

  
  # sets the RDBMS parameters as the user specified
  . ./scripts/setRdbmsConfig.sh
  
  
  # runs create RIM object script if new RIM object is to be created
  if [ $VERIFIED -ne 1 ]; then
  . ./scripts/rimCreateObject.sh
  fi      


  # updates create database SQL scripts as user specified
  . ./scripts/alterCrDbSql.sh 
  

  #runs create database SQL scripts
  . ./scripts/runCrDbSql.sh
  
  
  # tests RIM connection
  . ./scripts/rimCheckConnect.sh   
}

tmd_cr_db

  
