
--  Execute the following SQL fragment as the user of "Tivoli Manager for Domino 3.1"
--  It will create the necessary DB tables.
--
--  Property of TIVOLI Systems (April 2000)

CREATE TABLE TMD_SERVER(  \
        SERVER            varchar(255) NOT NULL,  \
        DOMAIN            varchar(255) NOT NULL,  \
        CLUSTER_NAME      varchar(255),  \
        RELEASE           varchar(32) NOT NULL,  \
        OS                varchar(32) NOT NULL,  \
        WEB               int NOT NULL,  \
        MAIL              int NOT NULL,  \
        MAILROUTER        int NOT NULL,  \
        DB                int NOT NULL,  \
        NEWS              int NOT NULL   \         
)

ALTER TABLE TMD_SERVER ADD CONSTRAINT TMD_PK1 PRIMARY KEY (SERVER)

CREATE TABLE TMD_MON ( \
        RUN_DATE          timestamp NOT NULL,  \
        RUN_TIME          varchar(8) NOT NULL,  \
        SERVER            varchar(64) NOT NULL,  \
        PROBE             varchar(64) NOT NULL,  \
        PROBE_ARG         varchar(255) NOT NULL,  \
        VALUE1            varchar(1024),  \
        VALUE2            varchar(192) NOT NULL   \
)

ALTER TABLE TMD_MON ADD CONSTRAINT TMD_PK2 PRIMARY KEY (RUN_DATE, RUN_TIME, SERVER, PROBE, PROBE_ARG, VALUE2)

CREATE INDEX TMD_INDEX1 ON TMD_MON (RUN_DATE, PROBE, PROBE_ARG)

CREATE INDEX TMD_INDEX2 ON TMD_MON (RUN_DATE)

CREATE TABLE TMD_REPORT(  \
        REPORT_NAME       varchar(255) NOT NULL,  \
        REPORT_TYPE	  varchar(16) NOT NULL,  \
        REPORT_DEF        varchar(1024) NOT NULL, \
        WEB               int NOT NULL,  \
        MAIL              int NOT NULL,  \
        MAILROUTER        int NOT NULL,  \
        DB                int NOT NULL,  \
        NEWS              int NOT NULL,  \        
        REPORT_VER        float NOT NULL  \        
)

ALTER TABLE TMD_REPORT ADD CONSTRAINT TMD_PK3 PRIMARY KEY (REPORT_NAME, REPORT_TYPE)

CREATE VIEW user_tab_columns \
    (TABLE_NAME, COLUMN_NAME, DATA_TYPE, DATA_LENGTH, \
     DATA_PRECISION, DATA_SCALE, NULLABLE, COLUMN_ID) \
AS \
    SELECT t.tabname, c.colname, c.typename, c.length, \
           c.length, c.scale, c.nulls, c.colno \
    FROM   syscat.tables t, syscat.columns c \
    WHERE  t.tabname = c.tabname

INSERT into TMD_REPORT VALUES ('DPSNABSearch','Graph','com.tivoli.tmd.ui.graph.TMDComparisonType;Shows up to 10 servers with the highest amount of time to perform a NAB lookup for the past week;probeMetric;com.tivoli.tmd.ui.graph.AverageMetric; ;probe;java.lang.String;DPSNABSearch ( %, %, %, names.nsf, People, % );returnType;com.tivoli.tmd.ui.graph.ReturnTop; ;groupBy;java.lang.String; ;returnCount;java.lang.Integer;10;timeframe;com.tivoli.tmd.ui.graph.RollingTimeframe;4',0,0,0,0,0,3.1)

INSERT into TMD_REPORT VALUES ('DPSRoundTripMail','Graph','com.tivoli.tmd.ui.graph.TMDComparisonType;Shows up to 10 servers with the highest amount of time to send a round trip email for the past week;probe;java.lang.String;DPSRoundTripMail ( %, %, %, 100, %, % );probeMetric;com.tivoli.tmd.ui.graph.AverageMetric; ;returnType;com.tivoli.tmd.ui.graph.ReturnTop; ;groupBy;java.lang.String; ;returnCount;java.lang.Integer;10;timeframe;com.tivoli.tmd.ui.graph.RollingTimeframe;4',0,0,0,0,0,3.1)

INSERT into TMD_REPORT VALUES ('Mail.TotalRouted','Graph','com.tivoli.tmd.ui.graph.TMDComparisonType;Shows up to 10 servers with the highest amount of mail routed for the past week;probeMetric;com.tivoli.tmd.ui.graph.AverageMetric; ;probe;java.lang.String;Mail ( MAIL.TotalRouted );returnType;com.tivoli.tmd.ui.graph.ReturnTop; ;groupBy;java.lang.String; ;returnCount;java.lang.Integer;10;timeframe;com.tivoli.tmd.ui.graph.RollingTimeframe;4',0,0,0,0,0,3.1)

INSERT into TMD_REPORT VALUES ('Server.AvailabilityIndex','Graph','com.tivoli.tmd.ui.graph.TMDComparisonType;Shows up to 10 servers with the lowest server availability for the past week;probe;java.lang.String;Server ( Server.AvailabilityIndex );probeMetric;com.tivoli.tmd.ui.graph.AverageMetric; ;returnType;com.tivoli.tmd.ui.graph.ReturnBottom; ;groupBy;java.lang.String; ;returnCount;java.lang.Integer;10;timeframe;com.tivoli.tmd.ui.graph.RollingTimeframe;4',0,0,0,0,0,3.1)

INSERT into TMD_REPORT VALUES ('Server.Sessions.Dropped','Graph','com.tivoli.tmd.ui.graph.TMDComparisonType;Shows up to 10 servers with the highest amount of dropped server sessions for the past week;probeMetric;com.tivoli.tmd.ui.graph.AverageMetric; ;probe;java.lang.String;Server ( Server.Sessions.Dropped );returnType;com.tivoli.tmd.ui.graph.ReturnTop; ;groupBy;java.lang.String; ;returnCount;java.lang.Integer;10;timeframe;com.tivoli.tmd.ui.graph.RollingTimeframe;4',0,0,0,0,0,3.1)
     
INSERT into TMD_REPORT VALUES ('Server.Users','Graph','com.tivoli.tmd.ui.graph.TMDComparisonType;Shows up to 10 servers with the highest amount of server users for the past week;probe;java.lang.String;Server ( Server.Users );probeMetric;com.tivoli.tmd.ui.graph.AverageMetric; ;returnType;com.tivoli.tmd.ui.graph.ReturnTop; ;groupBy;java.lang.String; ;returnCount;java.lang.Integer;10;timeframe;com.tivoli.tmd.ui.graph.RollingTimeframe;4',0,0,0,0,0,3.1)

INSERT into TMD_REPORT VALUES ('Server.Sessions.Dropped vs. Mem.Allocated','Graph','com.tivoli.tmd.ui.graph.TMDCorrelationType;Shows Server.Sessions.Dropped vs. Mem.Allocated for the specified server;subscriber;java.lang.String;<ServerName>;secondProbe;java.lang.String;Memory ( Mem.Allocated );probeMetric;com.tivoli.tmd.ui.graph.AverageMetric; ;probe;java.lang.String;Server ( Server.Sessions.Dropped );increment;com.tivoli.tmd.ui.graph.RollingTimeframe;10;secondProbeMetric;com.tivoli.tmd.ui.graph.AverageMetric; ;timeframe;com.tivoli.tmd.ui.graph.RollingTimeframe;5',0,0,0,0,0,3.1)

INSERT into TMD_REPORT VALUES ('Server.Users vs. Server.AvailabilityIndex','Graph','com.tivoli.tmd.ui.graph.TMDCorrelationType;Shows Server.Users vs. Server.AvailabilityIndex for the specified server;subscriber;java.lang.String;<ServerName>;secondProbe;java.lang.String;Server ( Server.AvailabilityIndex );probe;java.lang.String;Server ( Server.Users );probeMetric;com.tivoli.tmd.ui.graph.AverageMetric; ;increment;com.tivoli.tmd.ui.graph.RollingTimeframe;10;secondProbeMetric;com.tivoli.tmd.ui.graph.AverageMetric; ;timeframe;com.tivoli.tmd.ui.graph.RollingTimeframe;5',0,0,0,0,0,3.1)

INSERT into TMD_REPORT VALUES ('Swapdisk.Free vs. Server.Sessions.Dropped','Graph','com.tivoli.tmd.ui.graph.TMDCorrelationType;Shows Swapdisk.Free vs. Server.Sessions.Dropped for the specified server;subscriber;java.lang.String;<ServerName>;secondProbe;java.lang.String;Server ( Server.Sessions.Dropped );probeMetric;com.tivoli.tmd.ui.graph.AverageMetric; ;probe;java.lang.String;SwapDisk ( SwapDisk.Free );increment;com.tivoli.tmd.ui.graph.RollingTimeframe;10;secondProbeMetric;com.tivoli.tmd.ui.graph.AverageMetric; ;timeframe;com.tivoli.tmd.ui.graph.RollingTimeframe;5',0,0,0,0,0,3.1)

INSERT into TMD_REPORT VALUES ('Mail Report','Report','Report_Name=Mail Report' || CHR(10) || 'widths=20;20;10;10;20;20;10;10;0;0;0;0;' || CHR(10) || 'breaks=T;T;T;F;F;F;F;F;F;F;F;F;' || CHR(10) || 'totals=F;F;F;F;F;F;F;F;F;F;F;F;' || CHR(10) || 'averages=F;F;F;F;F;F;T;F;F;F;F;F;' || CHR(10) || 'criteria_indx=7' || CHR(10) || 'layout=1;2;7;8;9;10;11;12;0;0;0;0;' || CHR(10) || 'sortOrder=1;7;10;0;0;0;0;0;0;0;0;0;' || CHR(10) || 'sortOrderAscDesc=A;A;A;N;N;N;N;N;N;N;N;N;' || CHR(10) || 'pageSize_indx=3' || CHR(10) || 'rows_returned=0' || CHR(10) || 'criteriaOptions=' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '3;27;101;3;27;101;' || CHR(10) || '8;0;18;0;' || CHR(10) || 'Domino v5.0 Statistics Collection;Mail Trace;' || CHR(10) || '3;' || CHR(10) || 'in; ;' || CHR(10) || 'in; ;' || CHR(10) || '',0,0,0,0,0,3.1)

INSERT into TMD_REPORT VALUES ('Replication Report','Report','Report_Name=Replication Report' || CHR(10) || 'widths=20;20;10;10;20;20;10;10;0;0;0;0;' || CHR(10) || 'breaks=T;T;T;F;F;F;F;F;F;F;F;F;' || CHR(10) || 'totals=F;F;F;F;F;F;F;F;F;F;F;F;' || CHR(10) || 'averages=F;F;F;F;F;F;T;F;F;F;F;F;' || CHR(10) || 'criteria_indx=6' || CHR(10) || 'layout=1;2;7;8;9;10;11;12;0;0;0;0;' || CHR(10) || 'sortOrder=1;7;10;0;0;0;0;0;0;0;0;0;' || CHR(10) || 'sortOrderAscDesc=A;A;A;N;N;N;N;N;N;N;N;N;' || CHR(10) || 'pageSize_indx=3' || CHR(10) || 'rows_returned=0' || CHR(10) || 'criteriaOptions=' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '3;27;101;3;27;101;' || CHR(10) || '8;0;18;0;' || CHR(10) || 'Domino v5.0 Statistics Collection;Replication (Duration);' || CHR(10) || '%;' || CHR(10) || 'in; ;' || CHR(10) || 'in; ;' || CHR(10) || '',0,0,0,0,0,3.1)

INSERT into TMD_REPORT VALUES ('Server Availability Index','Report','Report_Name=Server Availability Index' || CHR(10) || 'widths=20;20;10;10;20;20;10;0;0;0;0;0;' || CHR(10) || 'breaks=T;T;F;F;F;F;F;F;F;F;F;F;' || CHR(10) || 'totals=F;F;F;F;F;F;F;F;F;F;F;F;' || CHR(10) || 'averages=F;F;F;F;F;F;T;F;F;F;F;F;' || CHR(10) || 'criteria_indx=7' || CHR(10) || 'layout=1;2;7;8;9;10;11;0;0;0;0;0;' || CHR(10) || 'sortOrder=1;7;0;0;0;0;0;0;0;0;0;0;' || CHR(10) || 'sortOrderAscDesc=A;A;N;N;N;N;N;N;N;N;N;N;' || CHR(10) || 'pageSize_indx=3' || CHR(10) || 'rows_returned=0' || CHR(10) || 'criteriaOptions=' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '3;27;101;3;27;101;' || CHR(10) || '8;0;18;0;' || CHR(10) || 'Domino v5.0 Statistics Collection;Server;' || CHR(10) || 'Server.AvailabilityIndex;' || CHR(10) || 'in; ;' || CHR(10) || 'in; ;' || CHR(10) || '',0,0,0,0,0,3.1)

INSERT into TMD_REPORT VALUES ('Server Uptime','Report','Report_Name=Server Uptime' || CHR(10) || 'widths=20;20;10;10;20;20;10;0;0;0;0;0;' || CHR(10) || 'breaks=T;T;F;F;F;F;F;F;F;F;F;F;' || CHR(10) || 'totals=F;F;F;F;F;F;F;F;F;F;F;F;' || CHR(10) || 'averages=F;F;F;F;F;F;T;F;F;F;F;F;' || CHR(10) || 'criteria_indx=7' || CHR(10) || 'layout=1;2;7;8;9;10;11;0;0;0;0;0;' || CHR(10) || 'sortOrder=1;7;0;0;0;0;0;0;0;0;0;0;' || CHR(10) || 'sortOrderAscDesc=A;A;N;N;N;N;N;N;N;N;N;N;' || CHR(10) || 'pageSize_indx=3' || CHR(10) || 'rows_returned=0' || CHR(10) || 'criteriaOptions=' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '' || CHR(10) || '3;27;101;3;27;101;' || CHR(10) || '8;0;18;0;' || CHR(10) || 'Domino v5.0 Statistics Collection;Server Availability;' || CHR(10) || ' ;' || CHR(10) || 'in; ;' || CHR(10) || 'in; ;' || CHR(10) || '',0,0,0,0,0,3.1)

