#!/bin/sh

 #=======================================================================
 #
 # Component:   Tivoli Manager for Domino 3.1
 #
 # Description: Updates the pre-canned tables for TMD 3.1 database
 #              (Modified from the dom_cr_db.sh)
 #
 # Author:      dtam
 #
 # Parameters:
 #
 # Returns:       0  - normal completion
 #                >0 - abnormal termination
 #
 # PROPERTY of TIVOLI Systems
 # April, 2000
 #
 # Adjustments :
 #
 # Defect  ID   Change Description
 # ------  ---  --------------------------------------------------------
 # 104913  TCT  Put in scripts to create RIM object and test connection
 # 
 #=======================================================================


#--------------------------------------------------------------------------------
# tmd_update_db()
#--------------------------------------------------------------------------------

tmd_update_db()
{
#set parameters: application name, rim name, db name
#db user id, db server name
. ./scripts/init.sh  


#checks Tivoli authorization
. ./scripts/tmeCheck.sh  


#tries to determine RDBMS vendor from RIM, 
#if failed, sets QUERY_VENDOR to 1.
. ./scripts/findRimVendor.sh 


#prompts user for RDBMS vendor name if not obtained from RIM                              
. ./scripts/findVendor.sh 


#searches for the update database scripts
. ./scripts/findUpdateDbScripts.sh 


# Checks for RIM connection, 
# Trys to find DB configuration from RIM
# Prompts user to verify search result. 
. ./scripts/rimCheckObject.sh   


# if RIM object is not found, prompts user for RDBMS parameters
. ./scripts/newRimRdbmsConfig.sh


# Sets Oracle specific parameters
. ./scripts/oracleSpecific.sh


# Sets DB2 specific parameters  
. ./scripts/db2Specific.sh 


# sets the RDBMS parameters as the user specified
. ./scripts/setRdbmsConfig.sh 


# updates update database SQL scripts
. ./scripts/alterUpdateDbSql.sh 
  

#runs update database SQL scripts
. ./scripts/runUpdateDbSql.sh
}

tmd_update_db

  
